@@ -305,9 +305,9 @@ class MDCClickCommand(FixedSubcommand):
         else:
             type = {
                 fields.Str: str,
+                fields.StrCoded: str,
                 fields.Bool: bool,
                 fields.Int: int,
-                fields.IntHL: int,
             }[field.__class__]
             help = type.__name__.lower()
             if type is int and field.range:
@@ -514,7 +514,13 @@ def asyncio_run(call, targets):
     if platform.system() == 'Windows':
         asyncio.set_event_loop_policy(
             asyncio.WindowsSelectorEventLoopPolicy())
-    loop = asyncio.get_event_loop()
+    try:
+        loop = asyncio.get_running_loop()
+        is_running_loop = True
+    except RuntimeError:
+        loop = asyncio.get_event_loop()
+        is_running_loop = False
+
     loop.run_until_complete(asyncio.wait([
         loop.create_task(call(*target))
         for target in targets
@@ -528,7 +534,8 @@ def asyncio_run(call, targets):
             for connection in connections
         ]))
 
-    loop.close()
+    if not is_running_loop:
+        loop.close()
 
 
 def register_command(command):
