@@ -27,7 +27,9 @@ class CommandMcs(type):
         ]
         dict['RESPONSE_DATA'] = [
             EnumField(x) if isinstance(x, type) and issubclass(x, Enum) else x
-            for x in dict.get('RESPONSE_DATA', dict['DATA'])
+            for x in dict.get(
+                'RESPONSE_DATA',
+                dict['DATA'] + dict.get('RESPONSE_EXTRA', []))
         ]
 
         cls = type.__new__(mcs, name, bases, dict)
@@ -52,7 +54,7 @@ class Command(metaclass=CommandMcs):
                 self.pack_payload_data(data) if data else []
             ),
         )
-        return self.parse_response_data(data)
+        return tuple(self.parse_response_data(data))
 
     def __get__(self, connection, cls):
         # Allow Command to be bounded as instance method
@@ -71,14 +73,17 @@ class Command(metaclass=CommandMcs):
     def parse_response_data(cls, data, strict_enum=True):
         rv, cursor = [], 0
         for field in cls.RESPONSE_DATA:
-            if not field.parse_len:
-                rv.append(field.parse(data[cursor:]))
-                cursor = None
-                break
-            rv.append(field.parse(data[cursor:cursor + field.parse_len]))
-            cursor += field.parse_len
+            try:
+                value, cursor_shift = field.parse(data[cursor:])
+            except Exception as exc:
+                raise MDCResponseError(
+                    f'Error parsing {field.name}: {exc}',
+                    data[cursor:]) from exc
 
-        if cursor is not None and data[cursor:]:
+            rv.append(value)
+            cursor += cursor_shift
+
+        if data[cursor:]:
             # Not consumed data left
             raise MDCResponseError('Unparsed data left', data[cursor:])
         return tuple(rv)
